@@ -6,8 +6,8 @@ use warnings;
 use strict;
 use 5.008;
 use Carp;
-our $VERSION = 0.02;
-use IO::Uncompress::Gunzip qw/gunzip $GunzipError/;
+our $VERSION = 0.03;
+use Gzip::Faster;
 
 # Nasty flag for debuggers
 
@@ -296,12 +296,11 @@ sub read_object
         return undef;
     }
     if ($type == miCOMPRESSED) {
-	print "Oh, you have $n_bytes of data.\n";
+#	print "Oh, you have $n_bytes of data.\n";
 	my $cdata = $obj->read_bytes ($n_bytes);
-	gunzip \$cdata, \my $uncdata
-	    or $obj->error ("gunzip failed: $GunzipError");
+	my $uncdata = gunzip ($cdata);
 	$obj->set_data ($uncdata);
-	print "Read again as uncompressed.\n";
+#	print "Read again as uncompressed.\n";
 	my $value = $obj->read_object ();
 	$obj->set_data (undef);
 	return $value;
